==> qdl_1.0.1.tar.gz: qdl-1.0.1/qdl-app/src/desktop/settingsdialog.cpp <==
#include "settingsdialog.h"
#include "downloadsettingstab.h"
#include "proxysettingstab.h"
#include "categorysettingstab.h"
#include "accountsettingstab.h"
#include "captchasettingstab.h"
#include "pluginsettingstab.h"
#include "../shared/pluginsettingsmodel.h"
#include <QVBoxLayout>
#include <QDialogButtonBox>
#include <QTabWidget>
#include <QPushButton>

SettingsDialog::SettingsDialog(QWidget *parent) :
    QDialog(parent)
{
    this->setWindowTitle(tr("Preferences"));
    this->setAttribute(Qt::WA_DeleteOnClose, true);
    this->setMinimumSize(600, 300);

    DownloadSettingsTab *downloadsTab = new DownloadSettingsTab(this);
    ProxySettingsTab *proxyTab = new ProxySettingsTab(this);
    CategorySettingsTab *categoriesTab = new CategorySettingsTab(this);
    AccountSettingsTab *accountsTab = new AccountSettingsTab(this);
    CaptchaSettingsTab *captchaTab = new CaptchaSettingsTab(this);
    PluginSettingsTab *pluginsTab = new PluginSettingsTab(this);

    QTabWidget *tabWidget = new QTabWidget(this);
    tabWidget->addTab(downloadsTab, tr("Downloads"));
    tabWidget->addTab(proxyTab, tr("Proxy"));
    tabWidget->addTab(categoriesTab, tr("Categories"));
    tabWidget->addTab(accountsTab, tr("Accounts"));
    tabWidget->addTab(captchaTab, tr("Decaptcha"));
    tabWidget->addTab(pluginsTab, tr("Plugins"));

    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Save | QDialogButtonBox::Cancel, Qt::Horizontal, this);
    buttonBox->button(QDialogButtonBox::Save)->setIcon(QIcon::fromTheme("document-save"));
    buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QIcon::fromTheme("dialog-cancel"));

    QVBoxLayout *vbox = new QVBoxLayout(this);
    vbox->addWidget(tabWidget);
    vbox->addWidget(buttonBox);

    this->connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
    this->connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
    this->connect(buttonBox, SIGNAL(accepted()), downloadsTab, SLOT(saveSettings()));
    this->connect(buttonBox, SIGNAL(accepted()), proxyTab, SLOT(saveSettings()));
}

SettingsDialog::~SettingsDialog() {}

==> qdl_1.0.4.tar.gz: qdl-1.0.4/qdl-app/src/desktop/settingsdialog.cpp <==
#include "settingsdialog.h"
#include "downloadsettingstab.h"
#include "proxysettingstab.h"
#include "categorysettingstab.h"
#include "accountsettingstab.h"
#include "captchasettingstab.h"
#include "pluginsettingstab.h"
#include "../shared/pluginsettingsmodel.h"
#include <QVBoxLayout>
#include <QDialogButtonBox>
#include <QTabWidget>
#include <QPushButton>

SettingsDialog::SettingsDialog(QWidget *parent) :
    QDialog(parent)
{
    this->setWindowTitle(tr("Preferences"));
    this->setAttribute(Qt::WA_DeleteOnClose, true);
    this->setMinimumSize(600, 300);

    DownloadSettingsTab *downloadsTab = new DownloadSettingsTab(this);
    ProxySettingsTab *proxyTab = new ProxySettingsTab(this);
    CategorySettingsTab *categoriesTab = new CategorySettingsTab(this);
    AccountSettingsTab *accountsTab = new AccountSettingsTab(this);
    CaptchaSettingsTab *captchaTab = new CaptchaSettingsTab(this);
    PluginSettingsTab *pluginsTab = new PluginSettingsTab(this);

    QTabWidget *tabWidget = new QTabWidget(this);
    tabWidget->addTab(downloadsTab, tr("General"));
    tabWidget->addTab(proxyTab, tr("Proxy"));
    tabWidget->addTab(categoriesTab, tr("Categories"));
    tabWidget->addTab(accountsTab, tr("Accounts"));
    tabWidget->addTab(captchaTab, tr("Decaptcha"));
    tabWidget->addTab(pluginsTab, tr("Plugins"));

    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Save | QDialogButtonBox::Cancel, Qt::Horizontal, this);
    buttonBox->button(QDialogButtonBox::Save)->setIcon(QIcon::fromTheme("document-save"));
    buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QIcon::fromTheme("dialog-cancel"));

    QVBoxLayout *vbox = new QVBoxLayout(this);
    vbox->addWidget(tabWidget);
    vbox->addWidget(buttonBox);

    this->connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
    this->connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
    this->connect(buttonBox, SIGNAL(accepted()), downloadsTab, SLOT(saveSettings()));
    this->connect(buttonBox, SIGNAL(accepted()), proxyTab, SLOT(saveSettings()));
}

SettingsDialog::~SettingsDialog() {}
